@@ -288,7 +288,7 @@ class TerminalInteractiveShell(InteractiveShell):
                             include_default_pygments_style=False,
                             mouse_support=self.mouse_support,
                             enable_open_in_editor=self.extra_open_editor_shortcuts,
-                            color_depth=(ColorDepth.TRUE_COLOR if self.true_color else None),
+                            color_depth=self.color_depth,
                             **self._extra_prompt_options())
 
     def _make_style_from_name_or_cls(self, name_or_cls):
@@ -365,6 +365,10 @@ class TerminalInteractiveShell(InteractiveShell):
             'readlinelike': CompleteStyle.READLINE_LIKE,
         }[self.display_completions]
 
+    @property
+    def color_depth(self):
+        return (ColorDepth.TRUE_COLOR if self.true_color else None)
+
     def _extra_prompt_options(self):
         """
         Return the current layout option for the current Terminal InteractiveShell
@@ -447,7 +451,7 @@ class TerminalInteractiveShell(InteractiveShell):
         # need direct access to the console in a way that we can't emulate in
         # GUI or web frontend
         if os.name == 'posix':
-            for cmd in ['clear', 'more', 'less', 'man']:
+            for cmd in ('clear', 'more', 'less', 'man'):
                 self.alias_manager.soft_define_alias(cmd, cmd)
 
 
