@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 """Nose-based test runner.
 """
 
@@ -6,12 +6,12 @@ from nose.core import main
 from nose.plugins.builtin import plugins
 from nose.plugins.doctests import Doctest
 
-import ipdoctest
-from ipdoctest import IPDocTestRunner
+from . import ipdoctest
+from .ipdoctest import IPDocTestRunner
 
 if __name__ == '__main__':
-    print 'WARNING: this code is incomplete!'
-    print
+    print('WARNING: this code is incomplete!')
+    print()
 
     pp = [x() for x in plugins]  # activate all builtin plugins first
     main(testRunner=IPDocTestRunner(),
